@@ -44,8 +44,8 @@ def cycling_CCCV(file_name,cycle_num):
     plt.legend()
     plt.xlabel('Capacity(Ah)')
     plt.ylabel('Voltage(V)')
-    fig = plt.gcf()
-    return(fig)
+    plt.show()
+    return()
 
 def diff_cap(file_name,cycle_num):
     '''
@@ -84,8 +84,9 @@ def diff_cap(file_name,cycle_num):
     plt.legend()
     plt.xlabel('Voltage(V)')
     plt.ylabel('dQ/dV')
-    fig = plt.gcf()
-    return (fig)
+    plt.show()
+    return ()
+
 
 def cycling_data_processing(df,cycle_num,data_type):
     '''
@@ -196,9 +197,10 @@ def Nyquist_plot(df):
     
     plt.plot(df['Z1'],-df['Z2'])
     plt.xlabel('Z1')
-    plt.ylabel('-Z1')
-    fig = plt.gcf()
-    return (fig)
+    plt.ylabel('-Z2')
+    plt.show()
+
+    return ()
     
 def dis_cap(df,max_cycle):
     '''
@@ -280,12 +282,12 @@ def dynamic_cycling(file_name):
         cycle1.set_color(colors(i))        
         
     anim = FuncAnimation(fig, animate, frames=np.arange(1,N,1), interval=50, repeat=True)    
-    plt.show()
     plt.xlabel('Capacity, [Ah]')
     plt.ylabel('Voltage, [V]')
     plt.xlim([-0.1,1.5])
     plt.ylim([2.4,4.3])
     fig.tight_layout()
+    plt.show()
     return anim
 
 
@@ -329,12 +331,13 @@ def dynamic_dqdv(file_name):
         
     anim = FuncAnimation(fig1, animate_1, frames=np.arange(1,N,1), interval=30, repeat=True)
     
-    plt.show()
+    
     plt.ylabel('dQdV, [Ah/V]')
     plt.xlabel('Voltage, [V]')
     plt.xlim([2.4,4.2])
     plt.ylim([-3,3])
     fig1.tight_layout()
+    plt.show()
     return anim
 def interactive_cycling(file_name):
     
