@@ -450,7 +450,7 @@ def cap_ret_online_NN(eis_data,cycling_data, hidden_layers_sizes, learning_rate,
     
     cap_ret_pred = online_NN.predict(input_features)
     
-    rel_err=mean_absolute_percentage_error(model.predict(X_test),y_test)
+    rel_err=mean_absolute_percentage_error(online_NN.predict(X_test),y_test)
 
     return (round(cap_ret_pred[0][cyc_num-1],2),round(cap_ret[0][cyc_num-1]*rel_err,2))
 
@@ -583,7 +583,7 @@ def cap_ret_online_NN_plot(eis_data,cycling_data, hidden_layers_sizes, learning_
     #Predict from given data
     
     cap_ret_pred = online_NN.predict(input_features)
-    err=average_err_per_cyc(y_test,model.predict(X_test))
+    err=average_err_per_cyc(y_test,online_NN.predict(X_test))
     fig, ax = plt.subplots(figsize=(8,6))
     fig.text(0.6,0.8,'Model $R^{2}$ = '+str(round(r2,2)))
     plt.plot(cap_ret[0],label='Prediction')
